@@ -33,5 +33,9 @@ func SplitAny(s string, seps string) []string {
 	splitter := func(r rune) bool {
 		return strings.ContainsRune(seps, r)
 	}
-	return strings.FieldsFunc(s, splitter)
+	result := strings.FieldsFunc(s, splitter)
+	if len(result) == 0 {
+		return []string{s}
+	}
+	return result
 }
