@@ -1,11 +1,14 @@
 package haskell
 
 import (
+	"context"
 	"fmt"
 	"io"
 
 	"gopkg.in/yaml.v3"
 
+	"github.com/anchore/syft/internal/log"
+	"github.com/anchore/syft/internal/unknown"
 	"github.com/anchore/syft/syft/artifact"
 	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
@@ -19,7 +22,7 @@ type stackYaml struct {
 }
 
 // parseStackYaml is a parser function for stack.yaml contents, returning all packages discovered.
-func parseStackYaml(_ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
+func parseStackYaml(_ context.Context, _ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	bytes, err := io.ReadAll(reader)
 	if err != nil {
 		return nil, nil, fmt.Errorf("failed to load stack.yaml file: %w", err)
@@ -28,7 +31,8 @@ func parseStackYaml(_ file.Resolver, _ *generic.Environment, reader file.Locatio
 	var stackFile stackYaml
 
 	if err := yaml.Unmarshal(bytes, &stackFile); err != nil {
-		return nil, nil, fmt.Errorf("failed to parse stack.yaml file: %w", err)
+		log.WithFields("error", err).Tracef("failed to parse stack.yaml file %q", reader.RealPath)
+		return nil, nil, fmt.Errorf("failed to parse stack.yaml file")
 	}
 
 	var pkgs []pkg.Package
@@ -39,13 +43,13 @@ func parseStackYaml(_ file.Resolver, _ *generic.Environment, reader file.Locatio
 			newPackage(
 				pkgName,
 				pkgVersion,
-				&pkg.HackageMetadata{
+				pkg.HackageStackYamlEntry{
 					PkgHash: pkgHash,
 				},
-				reader.Location.WithAnnotation(pkg.EvidenceAnnotationKey, pkg.PrimaryEvidenceAnnotation),
+				reader.Location,
 			),
 		)
 	}
 
-	return pkgs, nil, nil
+	return pkgs, nil, unknown.IfEmptyf(pkgs, "unable to determine packages")
 }
