@@ -4,13 +4,14 @@ Package python provides a concrete Cataloger implementation relating to packages
 package python
 
 import (
+	"github.com/anchore/syft/syft/pkg"
 	"github.com/anchore/syft/syft/pkg/cataloger/generic"
 )
 
 const eggInfoGlob = "**/*.egg-info"
 
 type CatalogerConfig struct {
-	GuessUnpinnedRequirements bool
+	GuessUnpinnedRequirements bool `yaml:"guess-unpinned-requirements" json:"guess-unpinned-requirements" mapstructure:"guess-unpinned-requirements"`
 }
 
 func DefaultCatalogerConfig() CatalogerConfig {
@@ -20,7 +21,7 @@ func DefaultCatalogerConfig() CatalogerConfig {
 }
 
 // NewPackageCataloger returns a new cataloger for python packages referenced from poetry lock files, requirements.txt files, and setup.py files.
-func NewPackageCataloger(cfg CatalogerConfig) *generic.Cataloger {
+func NewPackageCataloger(cfg CatalogerConfig) pkg.Cataloger {
 	rqp := newRequirementsParser(cfg)
 	return generic.NewCataloger("python-package-cataloger").
 		WithParserByGlobs(rqp.parseRequirementsTxt, "**/*requirements*.txt").
@@ -30,7 +31,7 @@ func NewPackageCataloger(cfg CatalogerConfig) *generic.Cataloger {
 }
 
 // NewInstalledPackageCataloger returns a new cataloger for python packages within egg or wheel installation directories.
-func NewInstalledPackageCataloger() *generic.Cataloger {
+func NewInstalledPackageCataloger() pkg.Cataloger {
 	return generic.NewCataloger("python-installed-package-cataloger").
 		WithParserByGlobs(
 			parseWheelOrEgg,
@@ -39,5 +40,5 @@ func NewInstalledPackageCataloger() *generic.Cataloger {
 			"**/*egg-info/PKG-INFO",
 			"**/*DIST-INFO/METADATA",
 			"**/*EGG-INFO/PKG-INFO",
-		)
+		).WithResolvingProcessors(wheelEggRelationships)
 }
