@@ -2,10 +2,12 @@ package ruby
 
 import (
 	"bufio"
+	"context"
 	"strings"
 
 	"github.com/scylladb/go-set/strset"
 
+	"github.com/anchore/syft/internal/unknown"
 	"github.com/anchore/syft/syft/artifact"
 	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
@@ -17,7 +19,7 @@ var _ generic.Parser = parseGemFileLockEntries
 var sectionsOfInterest = strset.New("GEM", "GIT", "PATH", "PLUGIN SOURCE")
 
 // parseGemFileLockEntries is a parser function for Gemfile.lock contents, returning all Gems discovered.
-func parseGemFileLockEntries(_ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
+func parseGemFileLockEntries(_ context.Context, _ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	var pkgs []pkg.Package
 	scanner := bufio.NewScanner(reader)
 
@@ -53,7 +55,7 @@ func parseGemFileLockEntries(_ file.Resolver, _ *generic.Environment, reader fil
 	if err := scanner.Err(); err != nil {
 		return nil, nil, err
 	}
-	return pkgs, nil, nil
+	return pkgs, nil, unknown.IfEmptyf(pkgs, "unable to determine packages")
 }
 
 func isDependencyLine(line string) bool {
